Cython: __init__.py

Generated by Cython 3.0.2

Yellow lines hint at Python interaction.
Click on a line that starts with a "`+`" to see the C code that Cython generated for it.

Raw output: __init__.c

    +1: # SPDX-FileCopyrightText: 2023-present joshua-auchincloss <joshua.auchincloss@proton.me>

      __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

     2: #

     3: # SPDX-License-Identifier: MIT

    +4: from fastomit.omit import Omitter, always_omit, globally_hidden, hide, reset_always

      __pyx_t_2 = PyList_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_n_s_Omitter);
      __Pyx_GIVEREF(__pyx_n_s_Omitter);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_Omitter)) __PYX_ERR(0, 4, __pyx_L1_error);
      __Pyx_INCREF(__pyx_n_s_always_omit);
      __Pyx_GIVEREF(__pyx_n_s_always_omit);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_always_omit)) __PYX_ERR(0, 4, __pyx_L1_error);
      __Pyx_INCREF(__pyx_n_s_globally_hidden);
      __Pyx_GIVEREF(__pyx_n_s_globally_hidden);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_globally_hidden)) __PYX_ERR(0, 4, __pyx_L1_error);
      __Pyx_INCREF(__pyx_n_s_hide);
      __Pyx_GIVEREF(__pyx_n_s_hide);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_hide)) __PYX_ERR(0, 4, __pyx_L1_error);
      __Pyx_INCREF(__pyx_n_s_reset_always);
      __Pyx_GIVEREF(__pyx_n_s_reset_always);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_s_reset_always)) __PYX_ERR(0, 4, __pyx_L1_error);
      __pyx_t_3 = __Pyx_Import(__pyx_n_s_fastomit_omit, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_Omitter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_Omitter, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_always_omit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_always_omit, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_globally_hidden); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_globally_hidden, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_hide); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_hide, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_reset_always); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_reset_always, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;